#[repr(i32)]pub enum EffectDirection {
None = 0,
TopLeft = 1,
Top = 2,
TopRight = 4,
Left = 8,
Center = 16,
Right = 32,
BottomLeft = 64,
Bottom = 128,
BottomRight = 256,
}Variants
None = 0
TopLeft = 1
Top = 2
TopRight = 4
Left = 8
Center = 16
Right = 32
BottomLeft = 64
Bottom = 128
BottomRight = 256
Implementations
Sourceimpl EffectDirection
impl EffectDirection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.