pub struct SlideText {
pub source_slide: i32,
pub source_option: i32,
pub preserve_notes_format: bool,
pub name_to_match: String,
pub element_text_transform: i32,
}Fields
source_slide: i32source_option: i32preserve_notes_format: boolname_to_match: Stringelement_text_transform: i32Implementations
Sourceimpl SlideText
impl SlideText
Sourcepub fn source_slide(&self) -> SlideSourceType
pub fn source_slide(&self) -> SlideSourceType
Returns the enum value of source_slide, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source_slide(&mut self, value: SlideSourceType)
pub fn set_source_slide(&mut self, value: SlideSourceType)
Sets source_slide to the provided enum value.
Sourcepub fn source_option(&self) -> TextSourceOption
pub fn source_option(&self) -> TextSourceOption
Returns the enum value of source_option, or the default if the field is set to an invalid enum value.
Sourcepub fn set_source_option(&mut self, value: TextSourceOption)
pub fn set_source_option(&mut self, value: TextSourceOption)
Sets source_option to the provided enum value.
Sourcepub fn element_text_transform(&self) -> TextTransformOption
pub fn element_text_transform(&self) -> TextTransformOption
Returns the enum value of element_text_transform, or the default if the field is set to an invalid enum value.
Sourcepub fn set_element_text_transform(&mut self, value: TextTransformOption)
pub fn set_element_text_transform(&mut self, value: TextTransformOption)
Sets element_text_transform to the provided enum value.